@@ -4,16 +4,29 @@
 use strict;
 use warnings;
 
-use Text::Xslate;
 use Text::MicroTemplate::Extended;
 use Template;
+use Getopt::Long;
 
 use Test::More;
 use Benchmark qw(:all);
 use FindBin qw($Bin);
 
-my $try_mst = grep { $_ eq '--mst' } @ARGV;
-@ARGV = grep { $_ ne '--mst' } @ARGV;
+GetOptions(
+    'mst' => \my $try_mst,
+    'pp'  => \my $pp,
+    'booster' => \my $pp_booster,
+);
+
+
+if ($pp) {
+    print "testing with PP\n";
+    $Template::Config::STASH = 'Template::Stash';
+    $ENV{XSLATE} = $pp_booster ? 'pp=booster' : 'pp';
+    $ENV{MOUSE_PUREPERL} = 1;
+}
+
+require Text::Xslate;
 
 my $tmpl   = !Scalar::Util::looks_like_number($ARGV[0]) && shift(@ARGV);
    $tmpl ||= 'list';
@@ -31,9 +44,12 @@ warn "Text::ClearSilver is not available ($@)\n" if $@;
 my $has_mst = ($tmpl eq 'list' && $try_mst && eval q{ use MobaSiF::Template; 1 });
 warn "MobaSiF::Template is not available ($@)\n" if $try_mst && $@;
 
-my $has_ht = eval q{ use HTML::Template::Pro; 1 };
+my $has_htp = eval q{ use HTML::Template::Pro; 1 };
 warn "HTML::Template::Pro is not available ($@)\n" if $@;
 
+my $has_ht = eval q{ use HTML::Template; 1 };
+warn "HTML::Template is not available ($@)\n" if $@;
+
 foreach my $mod(qw(
     Text::Xslate Text::MicroTemplate Template
     Text::ClearSilver MobaSiF::Template HTML::Template::Pro
@@ -71,15 +87,25 @@ if($has_mst) {
     MobaSiF::Template::Compiler::compile($mst_in, $mst_bin);
 }
 
-my $ht;
-if($has_ht) {
-    $ht = HTML::Template::Pro->new(
+my $htp;
+if($has_htp) {
+    $htp = HTML::Template::Pro->new(
         path           => [$path],
         filename       => "$tmpl.ht",
         case_sensitive => 1,
     );
 }
 
+my $ht;
+if($has_ht) {
+    $ht = HTML::Template->new(
+        path           => [$path],
+        filename       => "$tmpl.ht",
+        case_sensitive => 1,
+        die_on_bad_params => 0,
+    );
+}
+
 my $vars = {
     data => [ ({
             title    => "FOO",
@@ -96,6 +122,7 @@ my $vars = {
     my $tests = 2;
     $tests++ if $has_tcs;
     $tests++ if $has_mst;
+    $tests++ if $has_htp;
     $tests++ if $has_ht;
     plan tests => $tests;
 
@@ -119,11 +146,18 @@ my $vars = {
         is $out, $expected, 'MST: MobaSiF::Template';
     }
 
+    if($has_htp) {
+        $htp->param($vars);
+        $out = $htp->output();
+        $out =~ s/\n+/\n/g;
+        is $out, $expected, 'HTP: HTML::Template::Pro';
+    }
+
     if($has_ht) {
         $ht->param($vars);
         $out = $ht->output();
         $out =~ s/\n+/\n/g;
-        is $out, $expected, 'HT: HTML::Template::Pro';
+        is $out, $expected, 'HT: HTML::Template';
     }
 }
 
@@ -143,19 +177,26 @@ cmpthese -1 => {
         return;
     },
 
-    $has_tcs ? (
+    (!$pp && $has_tcs) ? (
         TCS => sub {
             my $body;
             $tcs->process("$tmpl.cs", $vars, \$body);
             return;
         },
     ) : (),
-    $has_mst ? (
+    (!$pp && $has_mst) ? (
         MST => sub {
             my $body = MobaSiF::Template::insert($mst_bin, $vars);
             return;
         },
     ) : (),
+    (!$pp && $has_htp) ? (
+        HTP => sub {
+            $htp->param($vars);
+            my $body = $htp->output();
+            return;
+        },
+    ) : (),
     $has_ht ? (
         HT => sub {
             $ht->param($vars);
